#!/bin/bash
[ ! -r /etc/udev/rules.d/11-spirit.rules ] && echo "Need to update UDEV rules .." && \
SUDO="sudo" && \
if which kdesu >/dev/null; then
    SUDO="kdesu"
else
	if which gksudo >/dev/null; then
		#SUDO="gksudo"
		SUDO="sudo"
	fi
fi && \
$SUDO bash -c 'echo "SUBSYSTEMS==\"usb\", ATTRS{product}==\"CP2102 USB to UART Bridge Controller\", ATTRS{idProduct}==\"ea60\", ATTRS{idVendor}==\"10c4\", SYMLINK+=\"spirit\", MODE=\"0666\"" > /etc/udev/rules.d/11-spirit.rules'

cd `dirname $0`
ARCH=`uname -m`

LD_LIBRARY_PATH=lib exec ./settings-$ARCH "$@"

rm -f /tmp/.spirit-settings
